﻿using System;
using System.Drawing;
using System.Windows.Forms;
using Telerik.WinControls.UI;

namespace _1070932
{
    public static class CommonEventHandler
    {
        private static Color chkDefBgColor;
        private static Color rdbDefBgColor;
        private static Color txtDefBgColor;
        private static Color ddlDefBgColor;

        public static void BindCommonEvents(object sender, EventArgs e)
        {
            var form = sender as RadForm;
            form.KeyDown += FormKeyDown;

            foreach (Control c in form.Controls)
                SetControlEvents(c);
        }

        private static void SetControlEvents(Control control)
        {
            if (control.ToString().Contains(value: "Label")) return;

            if (control.ToString().Contains(value: "GroupBox") || control.ToString().Contains(value: "Panel"))
            {
                SetControlEvents(control);
            }
            else
            {
                if (control is RadTextBox)
                {
                    var textBox = control as RadTextBox;
                    textBox.GotFocus += ControlGotFocus;
                    textBox.LostFocus += ControlLostFocus;
                    return;
                }
                if (control is RadDropDownList)
                {
                    var dropDownList = control as RadDropDownList;
                    dropDownList.GotFocus += ControlGotFocus;
                    dropDownList.LostFocus += ControlLostFocus;

                    if (dropDownList.DropDownStyle == Telerik.WinControls.RadDropDownStyle.DropDown)
                    {
                        dropDownList.DropDownListElement.TextBox.TextBoxItem.HostedControl.LostFocus += HostedControl_LostFocus;
                    }
                    
                    return;
                }
                if (control is RadCheckBox)
                {
                    var radCheckBox = control as RadCheckBox;
                    radCheckBox.GotFocus += ControlGotFocus;
                    radCheckBox.LostFocus += ControlLostFocus;
                    return;
                }
                if (control is RadRadioButton)
                {
                    var radRadioButton = control as RadRadioButton;
                    radRadioButton.GotFocus += ControlGotFocus;
                    radRadioButton.LostFocus += ControlLostFocus;
                }
            }
        }

        private static void HostedControl_LostFocus(object sender, EventArgs e)
        {
            var ddl = (sender as HostedTextBoxBase).Parent as RadDropDownList;
            ddl.BackColor = Color.White;
        }

        public static void FormKeyDown(object sender, KeyEventArgs e)
        {
            var activeForm = (RadForm) sender;
            if (e.KeyCode == Keys.Enter)
                activeForm.SelectNextControl(activeForm.ActiveControl, forward: true, tabStopOnly: true, nested: true, wrap: true);
        }

        public static void ControlGotFocus(object sender, EventArgs e)
        {
            if (sender is RadTextBox)
            {
                var radTextBox = sender as RadTextBox;
                txtDefBgColor = radTextBox.BackColor;
                radTextBox.BackColor = Color.Blue;
                return;
            }
            if (sender is RadDropDownList)
            {
                
                var radDropDownList = sender as RadDropDownList;

                ddlDefBgColor = radDropDownList.BackColor;
                radDropDownList.BackColor = Color.Blue;
                return;
            }

            if (sender is RadCheckBox)
            {
                var radCheckBox = sender as RadCheckBox;
                chkDefBgColor = radCheckBox.ButtonElement.CheckMarkPrimitive.Border.ForeColor;
                radCheckBox.ButtonElement.CheckMarkPrimitive.Border.ForeColor = Color.Blue;
                radCheckBox.ButtonElement.CheckMarkPrimitive.Border.Width++;
                return;
            }
            if (sender is RadRadioButton)
            {
                var radRadioButton = sender as RadRadioButton;
                rdbDefBgColor = radRadioButton.ButtonElement.CheckMarkPrimitive.BorderColor;
                radRadioButton.ButtonElement.CheckMarkPrimitive.BorderColor = Color.Blue;
                radRadioButton.ButtonElement.CheckMarkPrimitive.BorderWidth++;
            }
        }
        public static void ControlLostFocus(object sender, EventArgs e)
        {
            if (sender is RadTextBox)
            {
                var radTextBox = sender as RadTextBox;
                radTextBox.BackColor = Color.White;// txtDefBgColor;
                return;
            }

            if (sender is RadDropDownList)
            {
                var radDropDownList = sender as RadDropDownList;
                if (radDropDownList.DropDownListElement.TextBox.TextBoxItem.HostedControl.ContainsFocus)
                {
                    return;
                }

                radDropDownList.BackColor = Color.White;//ddlDefBgColor;
                return;
            }

            if (sender is RadCheckBox)
            {
                var radCheckBox = sender as RadCheckBox;
                radCheckBox.ButtonElement.CheckMarkPrimitive.Border.ForeColor = chkDefBgColor;
                radCheckBox.ButtonElement.CheckMarkPrimitive.Border.Width--;
                return;
            }

            if (sender is RadRadioButton)
            {
                var radRadioButton = sender as RadRadioButton;
                radRadioButton.ButtonElement.CheckMarkPrimitive.BorderColor = rdbDefBgColor;
                radRadioButton.ButtonElement.CheckMarkPrimitive.BorderWidth--;
            }
        }
    }
}
